"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _deepEqual = _interopRequireDefault(require("deep-equal"));

var _responses = require("@webiny/handler-graphql/responses");

var _NotAuthorizedResponse = _interopRequireDefault(require("@webiny/api-security/NotAuthorizedResponse"));

var _GraphQLSchemaPlugin = require("@webiny/handler-graphql/plugins/GraphQLSchemaPlugin");

var _default = new _GraphQLSchemaPlugin.GraphQLSchemaPlugin({
  typeDefs:
  /* GraphQL */
  `
        type SecurityGroup {
            name: String
            slug: String
            createdOn: DateTime
            description: String
            permissions: [JSON]
        }

        input SecurityGroupCreateInput {
            name: String!
            slug: String!
            description: String
            permissions: [JSON!]!
        }

        input SecurityGroupUpdateInput {
            name: String
            description: String
            permissions: [JSON!]
        }

        type SecurityGroupResponse {
            data: SecurityGroup
            error: SecurityError
        }

        type SecurityGroupListResponse {
            data: [SecurityGroup]
            error: SecurityError
        }

        extend type SecurityQuery {
            getGroup(slug: String): SecurityGroupResponse
            listGroups: SecurityGroupListResponse
        }

        extend type SecurityMutation {
            createGroup(data: SecurityGroupCreateInput!): SecurityGroupResponse
            updateGroup(slug: String!, data: SecurityGroupUpdateInput!): SecurityGroupResponse
            deleteGroup(slug: String!): SecurityBooleanResponse
        }
    `,
  resolvers: {
    SecurityQuery: {
      getGroup: async (_, {
        slug
      }, context) => {
        const {
          security,
          tenancy
        } = context;
        const permission = await security.getPermission("security.group");

        if (!permission) {
          return new _NotAuthorizedResponse.default();
        }

        try {
          const tenant = tenancy.getCurrentTenant();
          const group = await security.groups.getGroup(tenant, slug);

          if (!group) {
            return new _responses.NotFoundResponse(`Unable to find group with slug: ${slug}`);
          }

          return new _responses.Response(group);
        } catch (e) {
          return new _responses.ErrorResponse(e);
        }
      },
      listGroups: async (_, args, context) => {
        const {
          security,
          tenancy
        } = context;
        const permission = await security.getPermission("security.group");

        if (!permission) {
          return new _NotAuthorizedResponse.default();
        }

        try {
          const tenant = tenancy.getCurrentTenant();
          const groupList = await security.groups.listGroups(tenant);
          return new _responses.ListResponse(groupList);
        } catch (e) {
          return new _responses.ListErrorResponse(e);
        }
      }
    },
    SecurityMutation: {
      createGroup: async (_, {
        data
      }, context) => {
        const {
          security,
          tenancy
        } = context;
        const permission = await security.getPermission("security.group");

        if (!permission) {
          return new _NotAuthorizedResponse.default();
        }

        try {
          const tenant = tenancy.getCurrentTenant();
          const groupData = await security.groups.createGroup(tenant, data);
          return new _responses.Response(groupData);
        } catch (e) {
          return new _responses.ErrorResponse(e);
        }
      },
      updateGroup: async (_, {
        slug,
        data
      }, context) => {
        const {
          security,
          tenancy
        } = context;
        const permission = await security.getPermission("security.group");

        if (!permission) {
          return new _NotAuthorizedResponse.default();
        }

        try {
          const tenant = tenancy.getCurrentTenant();
          const existingGroup = await security.groups.getGroup(tenant, slug);

          if (!existingGroup) {
            return new _responses.NotFoundResponse(`Group "${slug}" was not found!`);
          }

          const permissionsChanged = !(0, _deepEqual.default)(data.permissions, existingGroup.permissions);
          await security.groups.updateGroup(tenant, slug, data);
          Object.assign(existingGroup, data);

          if (permissionsChanged) {
            await security.groups.updateUserLinks(tenant, existingGroup);
          }

          return new _responses.Response(existingGroup);
        } catch (e) {
          return new _responses.ErrorResponse(e);
        }
      },
      deleteGroup: async (_, {
        slug
      }, context) => {
        const {
          security,
          tenancy
        } = context;
        const permission = await security.getPermission("security.group");

        if (!permission) {
          return new _NotAuthorizedResponse.default();
        }

        try {
          const tenant = tenancy.getCurrentTenant();
          const group = await security.groups.getGroup(tenant, slug);

          if (!group) {
            return new _responses.NotFoundResponse(`Group "${slug}" was not found!`);
          }

          await security.groups.deleteGroup(tenant, slug);
          return new _responses.Response(true);
        } catch (e) {
          return new _responses.ErrorResponse(e);
        }
      }
    }
  }
});

exports.default = _default;
//# sourceMappingURL=group.gql.js.map